==> wordpress-3.1-my_MM.tar.gz: wordpress/wp-admin/setup-config.php <==
<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**
 * We are blissfully unaware of anything.
 */
define('WP_SETUP_CONFIG', true);

/**
 * Disable error reporting
 *
 * Set this to error_reporting( E_ALL ) or error_reporting( E_ALL | E_STRICT ) for debugging
 */
error_reporting(0);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
define('WP_DEBUG', false);
/**#@-*/

require_once(ABSPATH . WPINC . '/load.php');
require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/class-wp-error.php');
require_once(ABSPATH . WPINC . '/version.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('စိတ်မေကာင်းပါ၊ လုပ်ငန်းေဆာင်ရွက်မှုြပုလုပ်ရမည့် wp-config-sample.php ဖိုင်ကို လိုအပ်ပါသည်။ သင့် WordPress ထည့်သွင်းမှုမျ ဒီဖိုင်ကို ြပန်တင်ပို့ပါ။');

$configFile = file(ABSPATH . 'wp-config-sample.php');

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>'wp-config.php' ဖိုင် ရှိြပီးြဖစ်သည်။ ဒီဖိုင်ထဲရှိ ြပင်ဆင်သတ်မှတ်ချက်တစ်ခုခုကို ြပန်လည် ြပုြပင်လိုလျှင် ဒီဖိုင်ကို အရင်ဖျက်ပါ။ <a href='install.php'>အခု ထည့်သွင်းရန်</a>ြကိုးစားြကည့်နိုင်ပါသည်။</p>");

// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>The file 'wp-config.php' ဖိုင်သည် WordPress ထည့်သွင်းထားမှု၏ အဆင့်တစ်ဆင့်ြမင့်ေသာေနရာတွင် ရှိြပီးြဖစ်သည်။ ဒီဖိုင်ထဲရှိ ြပင်ဆင်သတ်မှတ်ချက်တစ်ခုခုကို ြပန်လည် ြပုြပင်လိုလျှင် ဒီဖိုင်ကို အရင်ဖျက်ပါ။ <a href='install.php'>အခု ထည့်သွင်းရန်</a>ြကိုးစားြကည့်နိုင်ပါသည်။</p>");

if ( version_compare( $required_php_version, phpversion(), '>' ) )
	wp_die( sprintf( /*WP_I18N_OLD_PHP*/'သင့်ဆာဗာသည် PHP ဗားရှင်း %1$s ြဖင့် အလုပ်လုပ်ေနသည်။ သို့ေသာ်  WordPress မှ အနည်းဆံုး %2$s ကိုလိုအပ်ပါသည်။'/*/WP_I18N_OLD_PHP*/, phpversion(), $required_php_version ) );

if ( !extension_loaded('mysql') && !file_exists(ABSPATH . 'wp-content/db.php') )
	wp_die( /*WP_I18N_OLD_MYSQL*/'သင့်PHP ထည့်သွင်းစဉ်က Wordpress မှ လိုအပ်ေသာ MySQL extension အား ထည့်သွင်းရန် ကျန်ရှိခဲ့သည်ဟုယူဆရသည်။'/*/WP_I18N_OLD_MYSQL*/ );

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress &rsaquo; ထည့်သွင်းတပ်ဆင်မှု ြပင်ဆင်သတ်မှတ်ချက် ဖိုင်</title>
<script type='text/javascript' src='http://yourmyanmar.com/zgayar.mini.js'></script>
<script type='text/javascript' src='http://yourmyanmar.com/ayarzg.mini.js'></script>
<script>
function stoperror(){
return true
}
window.onerror=stoperror
</script>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Welcome to WordPress မှ ြကိုဆိုပါတယ်။ မစတင်မှီ ေဒတာေဗ့ဆိုင်ရာ အချက်အလက်တစ်ချို့ကို လိုအပ်ပါတယ်။ ဆက်လက် လုပ်ေဆာင်မှု မြပုမှီ ေအာက်ပါ အမျိုးအမည်များကို သိရှိထားရန် လိုအပ်ပါသည်။</p>
<ol>
	<li>ေဒတာေဗ့ အမည်</li>
	<li>ေဒတာေဗ့ သံုးသူအမည်</li>
	<li>ေဒတာေဗ့ စကားဝှက်</li>
	<li>ေဒတာေဗ့ လက်ခံဝန်ေဆာင်မှုေပးသူ</li>
	<li>ဇယားေရှ့ဆက် (ေဒတာေဗ့တစ်ခုတည်းတွင် WordPress တစ်ခုထက်ပို၍ သံုးလိုလျှင်) </li>
</ol>
<p><strong>အေြကာင်းတစ်ခုခုေြကာင့် ဖိုင်အလိုလို ဖန်တီးြပုလုပ်ြခင်း အလုပ်မလုပ်ခဲ့လျှင် စိတ်မပူပါနှင့်။ ဒီမှာ လုပ်ေဆာင်သမျှက သင့် စနစ်အြပင်အဆင်ဖိုင်သို့ ေဒတာေဗ့ အချက်အလက်များ ြဖည့်သွင်းေပးြခင်းသာြဖစ်ပါသည်။ ရိုးရိုးပင် စာသားအယ်ဒီတာ ပရိုဂရမ်တစ်ခုတွင် <code>wp-config-sample.php</code> ဖိုင်ကို ဖွင့်၍ သင့် အချက်အလက်များကို ြဖည့်သွင်း၍ <code>wp-config.php</code> အမည်ြဖင့် သိမ်းလိုက်ပါ</strong></p>
<p>ြဖစ်နိုင်ေြခရှိသည်မှာ ဒီအချက်အားလံုးကို သင့် ဝဘ်ဝန်ေဆာင်မှု ေပးသူမှ သင့်ကို ေထာက်ပံ့ေပးထားြပီးြဖစ်သည်။ သင့်မှာ ဒီအချက်အလက်များ မရှိေသးလျှင် သင် ဆက်လက် မလုပ်ေဆာင်မှီ သူတို့ကို ဆက်သွယ်ရန် လိုအပ်ပါသည်။ အားလံုး အဆင်သင်ြဖစ်ြပီဆိုလျှင်&hellip;</p>

<p class="step"><a href="setup-config.php?step=1<?php if ( isset( $_GET['noapi'] ) ) echo '&amp;noapi'; ?>" class="button">ဆက်လုပ်လိုက်ြကစို့!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>ေအာက်တွင် သင့်ေဒတာေဗ့ ဆက်သွယ်မှု အေသးစိတ် အချက်များကို ြဖည့်သွင်းပါ။ ဒီအေြကာင်းေတွကို မေသချာေသးလျှင် သင့်ကို ဝန်ေဆာင်မှုေပးထားသူကို ဆက်သွယ်ပါ။</p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">ေဒတာေဗ့ အမည်</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>WP ြဖင့် ချိတ်ဆက်အလုပ်လုပ်မည့် ေဒတာေဗ့ အမည် </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">သံုးသူ အမည်</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>သင့် MySQL သံုးသူအမည်</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">စကားဝှက်</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>...ြပီးေတာ့ MySQL စကားဝှက်</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">ေဒတာေဗ့ လက်ခံဝန်ေဆာင်မှုေပးသူ</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td><code>localhost</code> ြဖင့် အလုပ်မြဖစ်လျှင် သင့် ဝဘ်ဝန်ေဆာင်မှုေပးသူထံမှ ဒီအချက်အလက်များကို ရရှိထားသင့်သည်။</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">ဇယား ေရှ့ဆက်</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>ေဒတာေဗ့တစ်ခုတည်းတွင် WordPress ထည့်သွင်းထားမှု အများအြပား ြပုလုပ်လိုလျှင် ဒါကို ေြပာင်းပါ။</td>
		</tr>
	</table>
	<?php if ( isset( $_GET['noapi'] ) ) { ?><input name="noapi" type="hidden" value="true" /><?php } ?>
	<p class="step"><input name="submit" type="submit" value="ေပးပို့ပါ" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if ( empty($prefix) )
		$prefix = 'wp_';

	// Validate $prefix: it can only contain letters, numbers and underscores
	if ( preg_match( '|[^a-z0-9_]|i', $prefix ) )
		wp_die( /*WP_I18N_BAD_PREFIX*/'<strong>မှားေနသည်</strong>: "Table Prefix" တွင် နံပါတ်များ၊ အက္ခရာများနှင့် ေအာက်မျဉ်းတို့သာ ပါဝင်၍ရပါသည်။'/*/WP_I18N_BAD_PREFIX*/ );

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( ! empty( $wpdb->error ) ) {
		$back = '<p class="step"><a href="setup-config.php?step=1" onclick="javascript:history.go(-1);return false;" class="button">ေနာက်တစ်ြကိမ် ြပန်ြကိုးစားပါ</a></p>';
		wp_die( $wpdb->error->get_error_message() . $back );
	}

	// Fetch or generate keys and salts.
	$no_api = isset( $_POST['noapi'] );
	require_once( ABSPATH . WPINC . '/plugin.php' );
	require_once( ABSPATH . WPINC . '/l10n.php' );
	require_once( ABSPATH . WPINC . '/pomo/translations.php' );
	if ( ! $no_api ) {
		require_once( ABSPATH . WPINC . '/class-http.php' );
		require_once( ABSPATH . WPINC . '/http.php' );
		wp_fix_server_vars();
		/**#@+
		 * @ignore
		 */
		function get_bloginfo() {
			return ( ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . str_replace( $_SERVER['PHP_SELF'], '/wp-admin/setup-config.php', '' ) );
		}
		/**#@-*/
		$secret_keys = wp_remote_get( 'https://api.wordpress.org/secret-key/1.1/salt/' );
	}

	if ( $no_api || is_wp_error( $secret_keys ) ) {
		$secret_keys = array();
		require_once( ABSPATH . WPINC . '/pluggable.php' );
		for ( $i = 0; $i < 8; $i++ ) {
			$secret_keys[] = wp_generate_password( 64, true, true );
		}
	} else {
		$secret_keys = explode( "\n", wp_remote_retrieve_body( $secret_keys ) );
		foreach ( $secret_keys as $k => $v ) {
			$secret_keys[$k] = substr( $v, 28, 64 );
		}
	}
	$key = 0;

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				$configFile[$line_num] = str_replace("database_name_here", $dbname, $line);
				break;
			case "define('DB_USER'":
				$configFile[$line_num] = str_replace("'username_here'", "'$uname'", $line);
				break;
			case "define('DB_PASSW":
				$configFile[$line_num] = str_replace("'password_here'", "'$passwrd'", $line);
				break;
			case "define('DB_HOST'":
				$configFile[$line_num] = str_replace("localhost", $dbhost, $line);
				break;
			case '$table_prefix  =':
				$configFile[$line_num] = str_replace('wp_', $prefix, $line);
				break;
			case "define('AUTH_KEY":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_KE":
			case "define('AUTH_SAL":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_SA":
				$configFile[$line_num] = str_replace('put your unique phrase here', $secret_keys[$key++], $line );
				break;
		}
	}
	if ( ! is_writable(ABSPATH) ) :
		display_header();
?>
<p>စိတ်မေကာင်းပါ၊ <code>wp-config.php</code> ဖိုင်ကို ေရး၍ မရပါ။</p>
<p><code>wp-config.php</code> ကို ကိုယ်တိုင် ြပုလုပ်၍ ေအာက်ပါစာသားများကို ထိုထဲတွင် ြဖည့်ကူးပါ။</p>
<textarea cols="98" rows="15" class="code"><?php
		foreach( $configFile as $line ) {
			echo htmlentities($line, ENT_COMPAT, 'UTF-8');
		}
?></textarea>
<p>ြပီးလျှင် "ထည့်သွင်းပါ" ကို ကလစ်နှိပ်ပါ"</p>
<p class="step"><a href="install.php" class="button">ထည့်သွင်းပါ</a></p>
<?php
	else :
		$handle = fopen(ABSPATH . 'wp-config.php', 'w');
		foreach( $configFile as $line ) {
			fwrite($handle, $line);
		}
		fclose($handle);
		chmod(ABSPATH . 'wp-config.php', 0666);
		display_header();
?>
<p>ကဲေကာင်းြပီ ! ထည့်သွင်းတပ်ဆင်မှုက ဒီအပိုင်းထိေတာ့ ေရာက်လာြပီ အခု WordPress က သင့် ေဒတာေဗ့နှင့် ဆက်သွယ်နိုင်ပါြပီ။ အဆင်သင့်ြဖစ်ြပီဆိုရင်၊ အချိန်ကျြပီ&hellip;</p>

<p class="step"><a href="install.php" class="button">ထည့်သွင်းပါ</a></p>
<?php
	endif;
	break;
}
?>
<script type="text/javascript">
original_content_font = 'ayar';
display_content_font = 'ayar';

function init() {
	// quit if this function has already been called
	if (arguments.callee.done) return;

	// flag this function so we don't do the same thing twice
	arguments.callee.done = true;

	if (original_content_font == 'zawgyi-one'){
		toA();
		}
	else if (original_content_font == 'ayar'){
		toZ();
		}
	if (display_content_font == 'zawgyi-one'){
		toZ();
	}
	else if (display_content_font == 'ayar'){
		toA();
	}
};

/* for Mozilla */
if (document.addEventListener) {
   document.addEventListener("DOMContentLoaded", init, false);
}

/* for Internet Explorer */
/*@cc_on @*/
/*@if (@_win32)
   document.write("<script defer src=ie_onload.js><"+"/script>");
/*@end @*/

/* for other browsers */
window.onload = init;
</script>

<div class="otf">
<a id="A" class="selected" href="javascript:" onclick="if 
(this.className=='selected')return;toA();this.className='selected';document.getElementById('Z').className=''">
AYAR FONT</a>
</div>
<div class="otf" style="right: 0px;">
<a id="Z" href="javascript:" onclick="if 
(this.className=='selected')return;toZ();this.className='selected';document.getElementById('A').className=''">

ZAWGYI FONT</a>
</div>
</body>
</html>

==> wordpress-3.4.2-my_MM.tar.gz: wordpress/wp-admin/setup-config.php <==
<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @internal This file must be parsable by PHP4.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**
 * We are blissfully unaware of anything.
 */
define('WP_SETUP_CONFIG', true);

/**
 * Disable error reporting
 *
 * Set this to error_reporting( E_ALL ) or error_reporting( E_ALL | E_STRICT ) for debugging
 */
error_reporting(0);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
define('WP_DEBUG', false);
/**#@-*/

require_once(ABSPATH . WPINC . '/load.php');
require_once(ABSPATH . WPINC . '/version.php');
wp_check_php_mysql_versions();

require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/class-wp-error.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('Sorry, I need a wp-config-sample.php file to work from. Please re-upload this file from your WordPress installation.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>'wp-config.php' ဖိုင်ရှိြပီး ြဖစ်ပါသည်။ ဒီဖိုင်ထဲရှိ မည်သည့် စနစ်အြပင်အဆင်ကို မဆို ြပန်လည် သတ်မှတ်ေပးလိုလျှင် ၎င်းဖိုင်ကို အရင်ဖျက်ပါ။ <a href='install.php'>ယခုပင် ထည့်သွင်းြခင်းကို </a>စမ်းသပ် ြပုလုပ်နိုင်ပါသည်။</p>");

// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>'wp-config.php' ဖိုင်သည် သင့် WordPress ထည့်သွင်းမှုအထက်ရှိ အဆင့်တစ်ဆင့်ြမင့်ေသာေနရာတွင် ရှိြပီးြဖစ်ပါသည်။ ဒီဖိုင်ထဲရှိ မည်သည့် စနစ်အြပင်အဆင်ကို မဆို ြပန်လည် သတ်မှတ်ေပးလိုလျှင် ၎င်းဖိုင်ကို အရင်ဖျက်ပါ။ <a href='install.php'>ယခုပင် ထည့်သွင်းြခင်းကို </a>စမ်းသပ် ြပုလုပ်နိုင်ပါသည်။</p>");

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" /><link rel="stylesheet" href="http://webfonts.ayar.co/css/styles.css?font=ayar_takhu" type="text/css" media="all" /><style type="text/css">*{font-family:ayar takhu, Ayar Takhu !important;}</style>
<title>WordPress &rsaquo; စနစ်ြပင်ဆင် သတ်မှတ်မှု ဖိုင်</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>WordPress မှ ြကိုဆိုပါတယ်။ မစတင်မီ ေဒတာေဗ့နှင့် ပတ်သက်သည့် အချက်အလက်အချို့ လိုအပ်ပါသည်။ ဆက်လက်လုပ်ေဆာင်မှု မြပုခင် ေအာက်ပါ အချက်အလက်များကို သိထားရန် လိုအပ်ပါသည်။</p>
<ol>
	<li>ေဒတာေဗ့ အမည်</li>
	<li>ေဒတာေဗ့ သံုးသူအမည်</li>
	<li>ေဒတာေဗ့ စကားဝှက်</li>
	<li>ေဒတာေဗ့ ဝန်ေဆာင်မှုေပးသူ</li>
	<li>ဇယားေရှ့ဆက် (ေဒတာေဗ့ တစ်ခုတည်းတွင် WordPress ထည့်သွင်းမှု အများအြပား ထည့်သွင်းထားလိုလျှင်) </li>
</ol>
<p><strong>အေြကာင်းတစ်ခုခုေြကာင့် ဖိုင်အလိုလို ဖန်တီးြပုလုပ်ြခင်း အလုပ်မလုပ်ခဲ့လျှင် စိတ်မပူပါနှင့်။ ဒီမှာ လုပ်ေဆာင်သမျှက သင့် စနစ်အြပင်အဆင်ဖိုင်သို့ ေဒတာေဗ့ အချက်အလက်များ ြဖည့်သွင်းေပးြခင်းသာြဖစ်ပါသည်။ ရိုးရိုးပင် စာသားအယ်ဒီတာ ပရိုဂရမ်တစ်ခုတွင် <code>wp-config-sample.php</code> ဖိုင်ကို ဖွင့်၍ သင့် အချက်အလက်များကို ြဖည့်သွင်းြပီး <code>wp-config.php</code> အမည်ြဖင့် သိမ်းလိုက်ပါ</strong></p>
<p>ြဖစ်နိုင်ေြခရှိသည်မှာ ဒီအချက်အားလံုးကို သင့် ဝဘ်ဝန်ေဆာင်မှု ေပးသူမှ သင့်ကို ေထာက်ပံ့ေပးထားြပီးြဖစ်သည်။ သင့်မှာ ဒီအချက်အလက်များ မရှိေသးလျှင် သင် ဆက်လက် မလုပ်ေဆာင်မှီ သူတို့ကို ဆက်သွယ်ရန် လိုအပ်ပါသည်။ အားလံုး အဆင်သင့်ြဖစ်ြပီဆိုလျှင်&hellip;</p>

<p class="step"><a href="setup-config.php?step=1<?php if ( isset( $_GET['noapi'] ) ) echo '&amp;noapi'; ?>" class="button">ဆက်လုပ်လိုက်ြကစို့!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>ေအာက်တွင် သင့်ေဒတာေဗ့ ဆက်သွယ်မှု အေသးစိတ် အချက်များကို ြဖည့်သွင်းပါ။ ဒီအေြကာင်းေတွကို မေသချာေသးလျှင် သင့်ကို ဝန်ေဆာင်မှုေပးထားသူကို ဆက်သွယ်ပါ။ </p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">ေဒတာေဗ့ အမည်</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>WP ြဖင့် ချိတ်ဆက်အလုပ်လုပ်မည့် ေဒတာေဗ့ အမည်။ </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">သံုးသူ အမည်</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>သင့် MySQL သံုးသူအမည်</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">စကားဝှက်</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>...ြပီးေတာ့ MySQL စကားဝှက်။</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">ေဒတာေဗ့ ဝန်ေဆာင်မှု ေပးသူ</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td><code>localhost</code> ြဖင့် အလုပ်မြဖစ်လျှင် သင့် ဝဘ်ဝန်ေဆာင်မှုေပးသူထံမှ ဒီအချက်အလက်များကို ရရှိထားသင့်သည်။</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">ဇယား ေရှ့ဆက်</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>ေဒတာေဗ့တစ်ခုတည်းတွင် WordPress ထည့်သွင်းထားမှု အများအြပား ြပုလုပ်လိုလျှင် ဒါကို ေြပာင်းပါ။</td>
		</tr>
	</table>
	<?php if ( isset( $_GET['noapi'] ) ) { ?><input name="noapi" type="hidden" value="true" /><?php } ?>
	<p class="step"><input name="submit" type="submit" value="ေပးပို့ပါ" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if ( empty($prefix) )
		$prefix = 'wp_';

	// Validate $prefix: it can only contain letters, numbers and underscores
	if ( preg_match( '|[^a-z0-9_]|i', $prefix ) )
		wp_die( /*WP_I18N_BAD_PREFIX*/'<strong>မှားေနသည်</strong>: "Table Prefix" တွင် နံပါတ်များ၊ အက္ခရာများနှင့် ေအာက်မျဉ်းတို့သာ ပါဝင်၍ရပါသည်။'/*/WP_I18N_BAD_PREFIX*/ );

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( ! empty( $wpdb->error ) ) {
		$back = '<p class="step"><a href="setup-config.php?step=1" onclick="javascript:history.go(-1);return false;" class="button">Try Again</a></p>';
		wp_die( $wpdb->error->get_error_message() . $back );
	}

	// Fetch or generate keys and salts.
	$no_api = isset( $_POST['noapi'] );
	require_once( ABSPATH . WPINC . '/plugin.php' );
	require_once( ABSPATH . WPINC . '/l10n.php' );
	require_once( ABSPATH . WPINC . '/pomo/translations.php' );
	if ( ! $no_api ) {
		require_once( ABSPATH . WPINC . '/class-http.php' );
		require_once( ABSPATH . WPINC . '/http.php' );
		wp_fix_server_vars();
		/**#@+
		 * @ignore
		 */
		function get_bloginfo() {
			return ( ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . str_replace( $_SERVER['PHP_SELF'], '/wp-admin/setup-config.php', '' ) );
		}
		/**#@-*/
		$secret_keys = wp_remote_get( 'https://api.wordpress.org/secret-key/1.1/salt/' );
	}

	if ( $no_api || is_wp_error( $secret_keys ) ) {
		$secret_keys = array();
		require_once( ABSPATH . WPINC . '/pluggable.php' );
		for ( $i = 0; $i < 8; $i++ ) {
			$secret_keys[] = wp_generate_password( 64, true, true );
		}
	} else {
		$secret_keys = explode( "\n", wp_remote_retrieve_body( $secret_keys ) );
		foreach ( $secret_keys as $k => $v ) {
			$secret_keys[$k] = substr( $v, 28, 64 );
		}
	}
	$key = 0;

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				$configFile[$line_num] = str_replace("database_name_here", $dbname, $line);
				break;
			case "define('DB_USER'":
				$configFile[$line_num] = str_replace("'username_here'", "'$uname'", $line);
				break;
			case "define('DB_PASSW":
				$configFile[$line_num] = str_replace("'password_here'", "'$passwrd'", $line);
				break;
			case "define('DB_HOST'":
				$configFile[$line_num] = str_replace("localhost", $dbhost, $line);
				break;
			case '$table_prefix  =':
				$configFile[$line_num] = str_replace('wp_', $prefix, $line);
				break;
			case "define('AUTH_KEY":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_KE":
			case "define('AUTH_SAL":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_SA":
				$configFile[$line_num] = str_replace('put your unique phrase here', $secret_keys[$key++], $line );
				break;
		}
	}
	if ( ! is_writable(ABSPATH) ) :
		display_header();
?>
<p>စိတ်မေကာင်းပါ၊ <code>wp-config.php</code> ဖိုင်ကို ေရး၍ မရပါ။</p>
<p><code>wp-config.php</code> ကို ကိုယ်တိုင် ြပုလုပ်၍ ေအာက်ပါစာသားများကို ထိုထဲတွင် ြဖည့်ကူးပါ။</p>
<textarea cols="98" rows="15" class="code"><?php
		foreach( $configFile as $line ) {
			echo htmlentities($line, ENT_COMPAT, 'UTF-8');
		}
?></textarea>
<p>ြပီးလျှင် "ထည့်သွင်းပါ" ကို ကလစ်နှိပ်ပါ"</p>
<p class="step"><a href="install.php" class="button">ထည့်သွင်းပါ</a></p>
<?php
	else :
		$handle = fopen(ABSPATH . 'wp-config.php', 'w');
		foreach( $configFile as $line ) {
			fwrite($handle, $line);
		}
		fclose($handle);
		chmod(ABSPATH . 'wp-config.php', 0666);
		display_header();
?>
<p>ကဲေကာင်းြပီ ! ထည့်သွင်းတပ်ဆင်မှုက ဒီအပိုင်းထိေတာ့ ေရာက်လာြပီ အခု WordPress က သင့် ေဒတာေဗ့နှင့် ဆက်သွယ်နိုင်ပါြပီ။ အဆင်သင့်ြဖစ်ြပီဆိုရင်၊ အချိန်ကျြပီ&hellip;</p>

<p class="step"><a href="install.php" class="button">ထည့်သွင်းပါ</a></p>
<?php
	endif;
	break;
}
?>
</body>
</html>
